Struct style::stylist::ExtraStyleData
[−]
[src]
pub struct ExtraStyleData {}This struct holds data which users of Stylist may want to extract from stylesheets which can be done at the same time as updating.